@@ -2,6 +2,7 @@ from ._helpers import OptimizeResult, minimize
 from .cmaes import minimize as cmaes
 from .cpso import minimize as cpso
 from .de import minimize as de
+from .na import minimize as na
 from .pso import minimize as pso
 from .vdcma import minimize as vdcma
 
@@ -11,6 +12,7 @@ __all__ = [
     "cmaes",
     "cpso",
     "de",
+    "na",
     "pso",
     "vdcma",
 ]
